#! /bin/bash

# check to see if this host is on the list
HOST_NAME=`hostname`
grep $HOST_NAME serverlist.props
CODE=$?
if [ $CODE -ne 0 ]; then 
    echo "This machine is not listed in serverlist.props so PowerQuotes cannot be installed."
    echo "Please either install on a listed host or add this host to serverlist.props."
    echo "IMPORTANT: serverlist.props MUST be the same on ALL severs, the stock ticker application, and the client."
    exit 1
fi


if [ "x$JAVA_HOME" == "x" ] || [ ! -d $JAVA_HOME ]; then 
     
    echo "looking for JAVA_HOME at /usr/local/j2sdk1.4.0"
    JAVA_HOME=/usr/local/j2sdk1.4.0
    
    if [ ! -d $JAVA_HOME ]; then
	echo "looking for JAVA_HOME at /usr/lib/java"
	JAVA_HOME=/usr/lib/java

	if [ ! -d $JAVA_HOME ]; then
	    echo "Please set JAVA_HOME. Exitting..."
	    exit
	fi
    fi
fi


echo "JAVA_HOME is set to $JAVA_HOME"

echo cp run.sh $JBOSS_HOME/bin
cp run.sh $JBOSS_HOME/bin
echo cp serverlist.props $JBOSS_HOME/bin
cp serverlist.props $JBOSS_HOME/bin


if [ "x$JBOSS_HOME" == "x" ] || [ ! -d "$JBOSS_HOME" ]; then 
    echo "Please set JBOSS_HOME. Exitting..."
    exit
fi

echo "JBOSS_HOME is set to $JBOSS_HOME"


echo "checking if MySQL drivers are installed..."

RESTART=false

if [ ! -f $JBOSS_HOME/server/default/lib/mysql-connector-java-2.0.14-bin.jar ]; then
    echo "$JBOSS_HOME/server/default/lib/mysql-connector-java-2.0.14-bin.jar was not found..."
    echo cp mysql-connector-java-2.0.14-bin.jar $JBOSS_HOME/server/default/lib
    cp mysql-connector-java-2.0.14-bin.jar $JBOSS_HOME/server/default/lib
    
    # let other write over this so they can redeploy on the same machine
    echo chmod g+w $JBOSS_HOME/server/default/lib/mysql-connector-java-2.0.14-bin.jar
    chmod g+w $JBOSS_HOME/server/default/lib/mysql-connector-java-2.0.14-bin.jar

    RESTART=true
fi


echo cp jndi.properties $JBOSS_HOME/server/default/conf
cp jndi.properties $JBOSS_HOME/server/default/conf

echo cp mysql-service.xml $JBOSS_HOME/server/default/deploy
cp mysql-service.xml $JBOSS_HOME/server/default/deploy

# let other write over this so they can redeploy on the same machine
echo chmod g+w $JBOSS_HOME/server/default/deploy/mysql-service.xml
chmod g+w $JBOSS_HOME/server/default/deploy/mysql-service.xml

echo chmod g+w $JBOSS_HOME/server/default/conf/jndi.properties
chmod g+w $JBOSS_HOME/server/default/conf/jndi.properties


#figure out the number of servers
NUM_SERVERS=`cat serverlist.props | grep "=" | grep -v "#" | wc -l | awk '{print $1}'`

#we need to figure out the server number of this server based on its host name
SERVER_NUM=`cat serverlist.props | grep $HOST_NAME | awk '{print $3}'`


# we need to adjust the JNDI name for the beans before we deploy
PQDEPLOY=$PWD  #remember where we are...
TMPDIR=/tmp/pqdeploy_tmp.$$
mkdir $TMPDIR
cd $TMPDIR

jar -xvf $PQDEPLOY/powerquotes.jar > /dev/null


#(commented AN) SUFFIX=_${1}
SUFFIX=_$SERVER_NUM

echo $SUFFIX

# find the jndi-name closing tag and prepends the bean num suffix to it
sed -e "s/\(<\/jndi-name>\)/${SUFFIX}\1/g" $TMPDIR/META-INF/jboss.xml > /tmp/jboss.xml.$$

#<ejb-name>ClientUpdate\)/\1${SUFFIX}/g 
#        s/\(<ejb-name>UPSession\)/\1${SUFFIX}/g 
#        s/\(<ejb-name>StateReplicator\)/\1${SUFFIX}/g 
#        s/\(<ejb-name>TickReceiver\)/\1${SUFFIX}/g 
#        s/\(<ejb-name>test\/SequenceGenerator\)/\1${SUFFIX}/g
#        s/\(<ejb-name>UserProfileBean\)/\1${SUFFIX}/g" 

# copy the modified file in place
cp /tmp/jboss.xml.$$ $TMPDIR/META-INF/jboss.xml

# just for some meaningful output
cat $TMPDIR/META-INF/jboss.xml | grep "<jndi-name>"

jar -cvf powerquotes.jar META-INF powerquotes > /dev/null

if [ ! -d /tmp/powerquotes_deploy ]; then
    echo "mkdir /tmp/powerquotes_deploy"
    mkdir /tmp/powerquotes_deploy
else
    echo "/tmp/powerquotes_deploy already exists"
fi

echo "cp powerquotes.jar /tmp/powerquotes_deploy"
cp powerquotes.jar /tmp/powerquotes_deploy

# let other write over this so they can redeploy on the same machine
#echo "chmod -R g+w /tmp/powerquotes_deploy"
#chmod -R g+w /tmp/powerquotes_deploy

# don't copy the jar, just link it to the real jar in /tmp 
# so we can run on multiple machines
echo ln -s -f /tmp/powerquotes_deploy/powerquotes.jar $JBOSS_HOME/server/default/deploy
ln -s -f /tmp/powerquotes_deploy/powerquotes.jar $JBOSS_HOME/server/default/deploy

# same thing - let this be easily clobbered - not needed for a symlink
#echo chmod g+w $JBOSS_HOME/server/default/deploy/powerquotes.jar
#chmod g+w $JBOSS_HOME/server/default/deploy/powerquotes.jar

# clean up after ourself
echo "cleaning up..."
echo "rm -rf $TMPDIR"
rm -rf $TMPDIR
echo "rm /tmp/jboss.xml.$$"
rm /tmp/jboss.xml.$$

if [ $RESTART = "true" ]; then
    echo "Please restart JBoss if it is already running in order to allow the new drivers to load."
fi

echo "PowerQuotes EJB install completed successfully"







